﻿using Hotline.Share.Enums.Order;
using MiniExcelLibs.Attributes;
using SqlSugar;
using System.ComponentModel.DataAnnotations;


namespace Hotline.Import
{
    public class ExcelContent
    {
        [Required(ErrorMessage = "来源 不能为空")]
        [ExcelColumnName("来源")]
        public string Source { get; set; }

        [Required(ErrorMessage = "编号 不能为空")]
        [ExcelColumnName("编号")]
        public string ExternalId { get; set; }

        [Required(ErrorMessage = "受理时间 不能为空")]
        [ExcelColumnName("受理时间")]
        public DateTime StartTime { get; set; }

        [Required(ErrorMessage = "标题 不能为空")]
        [ExcelColumnName("标题")]
        public string Title { get; set; }

        [Required(ErrorMessage = "期满时间 不能为空")]
        [ExcelColumnName("期满时间")]
        public DateTime ExpiredTime { get; set; }

        /// <summary>
        /// 一级部门名称
        /// </summary>
        [ExcelColumnName("一级部门")]
        public string? OrgLevelOneName { get; set; }

        /// <summary>
        /// 二级部门名称
        /// </summary>
        [ExcelColumnName("二级部门")]
        public string? OrgLevelTwoName { get; set; }

        [Required(ErrorMessage = "承办部门 不能为空")]
        [ExcelColumnName("承办部门")]
        public string ActualHandleOrgName { get; set; }

        [Required(ErrorMessage = "办结时间 不能为空")]
        [ExcelColumnName("办结时间")]
        public DateTime ActualHandleTime { get; set; }

        [Required(ErrorMessage = "受理类型 不能为空")]
        [ExcelColumnName("受理类型")]
        public string AcceptType { get; set; }

        [Required(ErrorMessage = "一级热点 不能为空")]
        [ExcelColumnName("一级热点")]
        public string HotspotNameOne { get; set; }

        [ExcelColumnName("二级热点")]
        public string HotspotNameTwo { get; set; }

        [ExcelColumnName("三级热点")]
        public string HotspotNameThree { get; set; }

        [ExcelColumnName("四级热点")]
        public string HotspotNameFour { get; set; }

        [ExcelColumnName("五级热点")]
        public string HotspotNameFive { get; set; }

        /// <summary>
        /// 区域名称
        /// </summary>
        [Required(ErrorMessage = "区域 不能为空")]
        [ExcelColumnName("区域")]
        public string Address { get; set; }

        [ExcelColumnName("事发地址")]
        public string Street { get; set; }

        [Required(ErrorMessage = "来电人姓名 不能为空")]
        [ExcelColumnName("来电人姓名")]
        public string FromName { get; set; }

        [Required(ErrorMessage = "联系电话 不能为空")]
        [ExcelColumnName("联系电话")]
        public string Contact { get; set; }

        /// <summary>
        /// 是否超期(是或否)
        /// "是" or "否"
        /// </summary>
        [ExcelColumnName("是否超期")]
        public string IsExpired { get; set; }

        /// <summary>
        /// 默认 0
        /// </summary>
        [Required(ErrorMessage = "重办次数 不能为空")]
        [ExcelColumnName("重办次数")]
        public int ReTransactNum { get; set; }

        [Required(ErrorMessage = "信件满意度 不能为空")]
        [ExcelColumnName("信件满意度")]
        public string VisitResult { get; set; }

        [Required(ErrorMessage = "受理内容 不能为空")]
        [ExcelColumnName("受理内容")]
        public string Content { get; set; }

        [Required(ErrorMessage = "承办意见 不能为空")]
        [ExcelColumnName("承办意见")]
        public string ActualOpinion { get; set; }

        /// <summary>
        /// 链接
        /// TODO 没有存
        /// </summary>
        [ExcelColumnName("链接")]
        public string Link { get; set; }
    }
}
